

import os

CHARACTER_SIZES = [32, 64, 128, 256, 512, 1024]
CORPORATION_SIZES = [32, 64, 128, 256]
ALLIANCES_SIZES = [32, 64, 128]
FACTION_SIZES = [32, 64, 128]
TYPE_SIZES = [32, 64, 128, 256, 512]

def get_character_links(character_id):
    """ Takes a character ID and returns a dict with all available size links.

    :param character_id: A character ID from EVE.
    :return: A dict of size and urls.
    """

    return_dict = {x: get_image_server_link(character_id, 'char', x) for x in CHARACTER_SIZES}

    return return_dict


def get_corporation_links(corporation_id):
    """ Takes a corporation ID and returns a dict with all available size links.

    :param corporation_id: A corporation ID from EVE.
    :return: A dict of size and urls.
    """

    return_dict = {x: get_image_server_link(corporation_id, 'corp', x) for x in CORPORATION_SIZES}

    return return_dict

def get_alliance_links(alliance_id):
    """ Takes a alliance ID and returns a dict with all available size links.

    :param alliance_id: A alliance ID from EVE.
    :return: A dict of size and urls.
    """

    return_dict = {x: get_image_server_link(alliance_id, 'alli', x) for x in ALLIANCES_SIZES}

    return return_dict

def get_faction_links(faction_id):
    """ Takes a faction ID and returns a dict with all available size links.

    :param faction_id: A faction ID from EVE.
    :return: A dict of size and urls.
    """

    return get_alliance_links(faction_id)

def get_type_links(type_id):
    """ Takes a type ID and returns a dict with all available size links.

    :param type_id: A type ID from EVE.
    :return: A dict of size and urls.
    """

    return_dict = {x: get_image_server_link(type_id, 'type', x) for x in TYPE_SIZES}

    return return_dict


def get_image_server_link(image_id, image_type, icon_size=128):
    """Takes an ID and type name and builds and image server URL.

    Known valid sizes:
    Character: 32, 64, 128, 256, 512, 1024
    Corporation: 32, 64, 128, 256
    Alliance: 32, 64, 128
    Faction: 32, 64, 128
    Types: 32, 64, 128, 256, 512

    :param image_id: ID to be used in the URL.
    :param image_type: Valid string options are: char, corp, alli, fac, type
    :param icon_size: See doc string for valid image sizes.
    :return: A full URL to the CCP image server.
    """

    base_image_server_url = os.environ.get('IMAGE_SERVER_URL', 'https://image.eveonline.com/')

    if image_type == 'char':
        url_type = 'Character'
        url_format = 'jpg'

    elif image_type == 'corp':
        url_type = 'Corporation'
        url_format = 'png'

    elif image_type == 'alli':
        url_type = 'Alliance'
        url_format = 'png'

    elif image_type == 'fac':
        url_type = 'Alliance'
        url_format = 'png'

    else:
        url_type = 'Render'
        url_format = 'png'

    full_url = '{}{}/{}_{}.{}'.format(base_image_server_url, url_type, image_id, icon_size, url_format)

    return full_url





import mock
import unittest2

import eveimageserver

class EVEImageServerTestCase(unittest2.TestCase):
    """ Test for the EVE Image Server package. """

    def setUp(self):
        pass

    @mock.patch('os.environ.get')
    def test_get_image_server_link_os_variable(self, mock_os):
        """ Tests that the method properly uses a URL from the environment variables. """

        mock_os.return_value = 'http://example.com/'
        image_link = eveimageserver.get_image_server_link(1234, 'type')

        self.assertEqual(image_link, 'http://example.com/Render/1234_128.png')

    @mock.patch('os.environ.get')
    def test_get_character_links(self, mock_os):
        """ Test get_character_links gets the correct dictionary back. """

        mock_os.return_value = 'http://example.com/'
        links = eveimageserver.get_character_links(123456)

        self.assertEqual(
            links,
            {
                32: 'http://example.com/Character/123456_32.jpg',
                64: 'http://example.com/Character/123456_64.jpg',
                128: 'http://example.com/Character/123456_128.jpg',
                256: 'http://example.com/Character/123456_256.jpg',
                512: 'http://example.com/Character/123456_512.jpg',
                1024: 'http://example.com/Character/123456_1024.jpg',
            }
        )

    @mock.patch('os.environ.get')
    def test_get_corporation_links(self, mock_os):
        """ Test get_corporation_links gets the correct dictionary back. """

        mock_os.return_value = 'http://example.com/'
        links = eveimageserver.get_corporation_links(123456)

        self.assertEqual(
            links,
            {
                32: 'http://example.com/Corporation/123456_32.png',
                64: 'http://example.com/Corporation/123456_64.png',
                128: 'http://example.com/Corporation/123456_128.png',
                256: 'http://example.com/Corporation/123456_256.png',
            }
        )

    @mock.patch('os.environ.get')
    def test_get_alliance_links(self, mock_os):
        """ Test get_alliance_links gets the correct dictionary back. """

        mock_os.return_value = 'http://example.com/'
        links = eveimageserver.get_alliance_links(123456)

        self.assertEqual(
            links,
            {
                32: 'http://example.com/Alliance/123456_32.png',
                64: 'http://example.com/Alliance/123456_64.png',
                128: 'http://example.com/Alliance/123456_128.png',
            }
        )

    @mock.patch('os.environ.get')
    def test_get_faction_links(self, mock_os):
        """ Test get_faction_links gets the correct dictionary back. """

        mock_os.return_value = 'http://example.com/'
        links = eveimageserver.get_faction_links(123456)

        self.assertEqual(
            links,
            {
                32: 'http://example.com/Alliance/123456_32.png',
                64: 'http://example.com/Alliance/123456_64.png',
                128: 'http://example.com/Alliance/123456_128.png',
            }
        )

    @mock.patch('os.environ.get')
    def test_get_type_links(self, mock_os):
        """ Test get_type_links gets the correct dictionary back. """

        mock_os.return_value = 'http://example.com/'
        links = eveimageserver.get_type_links(123456)

        self.assertEqual(
            links,
            {
                32: 'http://example.com/Render/123456_32.png',
                64: 'http://example.com/Render/123456_64.png',
                128: 'http://example.com/Render/123456_128.png',
                256: 'http://example.com/Render/123456_256.png',
                512: 'http://example.com/Render/123456_512.png',
            }
        )

    @mock.patch('os.environ.get')
    def test_get_image_server_link_fac_type(self, mock_os):
        """ Test get_image_server_link gets the correct link for fac image_type. """

        mock_os.return_value = 'http://example.com/'
        image_link = eveimageserver.get_image_server_link(123456, 'fac', 128)

        self.assertEqual(
            image_link, 'http://example.com/Alliance/123456_128.png'
        )





import os

from eveimageserver import __version__
from setuptools import setup, find_packages

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name="eveimageserver",
    version=__version__,
    author="Regner Blok-Andernse",
    author_email="regnerba@gmail.com",
    description=("A collection of utility metods for interacting with the EVE Online image server."),
    license="MIT",
    keywords="eve image server",
    url="https://github.com/Regner/eveimageserver",
    packages=find_packages(),
    long_description=open('README.md').read(),
    install_requires=[line.strip() for line in open('requirements.txt')],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
    ],
)
